PodBool

Struct PodBool 

pub struct PodBool(/* private fields */);
A version of bool that has the same layout as bool but is bytemuck::Pod.

In Rust, bool has a defined representation of being one byte with false being 0 and true being 1. However, it is not Pod because it is invalid to interpret a byte that contains any value other than 0 or 1 as a bool – doing so is undefined behavior.

Use this type to get around that limitation, as PodBool is valid for any value of u8, and its value is checked to be valid as a bool upon calling as_bool

Implementations